@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Box;
 
-# $Id: Box.pm,v 1.16 2002/01/02 02:43:54 lachoy Exp $
+# $Id: Box.pm,v 1.18 2003/02/17 21:41:11 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper qw ( Dumper );
 
 @OpenInteract::Handler::Box::ISA     = ();
-$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Box::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Box::default_method    = '';
@@ -32,11 +32,16 @@ sub process_boxes {
     my $params = {};
 
     # First, do the system boxes -- this puts box information into the
-    # box holding area
+    # box holding area. (We need to be sure we always have access to
+    # the system box class...)
 
     my $system_box_class = $BOX_CONFIG->{system_box_handler};
+    eval "require $system_box_class";
+
     my $system_box_method = $BOX_CONFIG->{system_box_method} || DEFAULT_METHOD;
-    $system_box_class->$system_box_method();
+    if ( $system_box_class and $system_box_method ) {
+        $system_box_class->$system_box_method();
+    }
 
     # If a website has boxes that it's adding on every page it can do
     # so in code rather than in a template. Note that this handler can
@@ -46,12 +51,20 @@ sub process_boxes {
     my $custom_box_class = $BOX_CONFIG->{custom_box_handler};
     if ( $custom_box_class ) {
         eval "require $custom_box_class";
-        my $custom_box_method = $BOX_CONFIG->{custom_box_method} || DEFAULT_METHOD;
-        $R->DEBUG && $R->scrib( "Calling custom box handler:",
-                                "$custom_box_class\->$custom_box_method" );
-        eval { $custom_box_class->$custom_box_method() };
         if ( $@ ) {
-            $R->scrib( 0, "Cannot call custom box handler: $custom_box_class. Error: $@" );
+            $R->scrib( 0, "FAILED: cannot require custom box class ",
+                          "[$custom_box_class]: $@" );
+        }
+        else {
+            my $custom_box_method = $BOX_CONFIG->{custom_box_method}
+                                    || DEFAULT_METHOD;
+            $R->DEBUG && $R->scrib( "Calling custom box handler:",
+                                    "$custom_box_class\->$custom_box_method" );
+            eval { $custom_box_class->$custom_box_method() };
+            if ( $@ ) {
+                $R->scrib( 0, "FAILED: cannot call custom box handler ",
+                              "$custom_box_class\->$custom_box_method: $@" );
+            }
         }
     }
 
@@ -64,6 +77,7 @@ sub process_boxes {
 
     my %good_boxes = ();
     my @to_remove  = ();
+
 BOX:
     foreach my $box_info ( @{ $R->{boxes} } ) {
 
@@ -72,7 +86,7 @@ BOX:
 
         unless ( ref $box_info ) {
             $box_info = { name => $box_info, template => $box_info };
-            $R->DEBUG && $R->scrib( 1, "Found box with old scalar name-only call: $box_info->{name}" );
+            $R->scrib( 0, "DEPRECATED: Found box with old scalar name-only call [$box_info->{name}]" );
         }
 
         # See if this is a 'remove' request
@@ -106,7 +120,7 @@ BOX:
                 foreach my $box_key ( @BOX_KEYS ) {
                     $R->DEBUG && $R->scrib( 1, "Box information from action table:",
                                                "($box_key) = ($lookup_box_info->{ $box_key })" );
-                    $box_info->{ $box_key }  = $lookup_box_info->{ $box_key };
+                    $box_info->{ $box_key }  ||= $lookup_box_info->{ $box_key };
                 }
             }
 
@@ -179,7 +193,8 @@ BOX:
 
         if ( $box_info->{base_template} eq BLANK_SHELL_TEMPLATE() ) {
             $box_content = $html;
-            $R->DEBUG && $R->scrib( 1, "No wrapper template used by request, box is naked! (cover your eyes)" );
+            $R->DEBUG && $R->scrib( 1, "No wrapper template used by request, ",
+                                       "box is naked! (cover your eyes)" );
         }
         else {
             $shell_params->{content} = $html;
@@ -218,30 +233,106 @@ OpenInteract::Handler::Box -- Handle input and output for independent "boxes"
 
 =head1 SYNOPSIS
 
- # Define box information in your server.perl
+ # Deposit all boxes in the current location on the page:
 
- box => {
-    handler           => 'MyWebsite::Handler::Box',
-    default_separator => '--',
-    default_method    => 'run_box',
-    default_template  => 'base_box::main_box_shell',
- },
+ [% OI.comp( 'boxes' ) %]
 
- # Add a box
+ # Define global box information in your server.ini
+
+ [box]
+ handler            = MyWebsite::Handler::Box
+ default_template   = base_box::main_box_shell
+ default_separator  = <br>
+ default_method     = run_box
+ system_box_handler = MyWebsite::Handler::SystemBoxes
+ system_box_method  =
+ custom_box_handler =
+ custom_box_method  =
+
+ # Define an OI action (in conf/action.perl) to be used for a box with
+ # a class and method:
+
+ $action => {
+   current_weather_box => {
+      class    => 'OpenInteract::Handler::Weather',
+      method   => 'box',
+      weight   => 5,
+      title    => 'Current Weather',
+   },
+ };
+
+ # Add a box ('name' maps to the above OI action):
 
  my $zip = $R->{auth}{user}{zip_code};
- my $box = { name   => 'current_weather',
+ my $box = { name   => 'current_weather_box',
              weight => 2,
              title  => "Weather in Zip Code $zip",
              params => { zip_code => $zip };
  push @{ $R->{boxes} }, $box;
 
+ # Add the same box from a template:
+
+ [% user_zip = OI.login.zip_code;
+    OI.box_add( 'current_weather_box',
+                weight   = 2,
+                title    = "Weather in Zip Code $user_zip",
+                zip_code = $user_zip ) -%]
+
+ # Define an OI action (in conf/action.perl) to be used for a
+ # template-only box:
+
+ $action => {
+  'frequent_links_box' => {
+    name       => 'frequent_links_box',
+    template   => 'mypkg::box_frequent_links',
+    weight     => 8,
+    title      => 'Frequent Links',
+    security   => 'no',
+  },
+
+ # Add a template-only box, overriding weight and title:
+
+ my $box = { name   => 'frequent_links_box',
+             weight => 2,
+             title  => "Most visited sites" };
+ push @{ $R->{boxes} }, $box;
+
+ # Add the same box from a template, overriding title:
+
+ [% OI.box_add( 'frequent_links_box',
+                title  = 'Most visited sites' ) %]
+
  # Remove a box added in another part of the system
 
  push @{ $R->{boxes} }, { name => 'motd', remove => 'yes' };
 
+ # Remove the same box from a template
+
+ [% OI.box_add( 'motd', remove = 'yes' ) %]
+
 =head1 DESCRIPTION
 
+Boxes are standalone parcels of content that conform to a particular
+format. Think of each box as an OpenInteract action: that action may
+be a piece of code (method in a class) or it may simply be a template.
+
+In either case, the action generates content and the box handler sorts
+the boxes and places the content for each in a 'shell' so all the
+boxes look the same. The standard box looks something like this:
+
+ ------------------------- <-- 'shell'
+ |      BOX TITLE        |
+ -------------------------
+ | Box content as        |
+ | generated by an       |
+ | action or a           |
+ | template goes here    |
+ -------------------------
+
+But you can create your own shell by defining the key 'box_template'
+in your theme to be a particular template (in the
+'package::template_name' format).
+
 =head1 CONFIGURATION
 
 This module allows you to define default information in two separate
@@ -249,8 +340,8 @@ locations for a number of parameters.
 
 =head2 Server Configuration
 
-In the C<conf/server.perl> file found in every OpenInteract website,
-you can define certain information for your boxes.
+In the server configuration found in every OpenInteract website, you
+can define certain information for your boxes under the 'box' key:
 
 =over 4
 
@@ -259,8 +350,8 @@ you can define certain information for your boxes.
 B<handler> ($) (mandatory)
 
 Define the class that will be used to process the boxes. Unless you
-write your own class, this will B<always> be C<OpenInteract::Box> and
-should not be changed.
+write your own class, this will B<always> be
+C<OpenInteract::Handler:Box> and should not be changed.
 
 =item *
 
@@ -270,11 +361,11 @@ This is the string used to separate boxes. For instance, if you want
 to put a short horizontal rule between each line, you could set this
 to:
 
-  separator => '<hr width="50%" noshade/>'
+  separator = <hr width="50%" noshade/>
 
 Or if you had a custom image you wanted to separate your boxes with:
 
-  separator => '<div align="center"><img src="/images/box_sep.gif" height="2" width="25"/></div>',
+  separator = <div align="center"><img src="/images/box_sep.gif" height="2" width="25"/></div>
 
 This module defines the default separator as '<br>'. It will be used
 only if there is no separator defined in the theme or in the server
@@ -296,10 +387,39 @@ This is the template into which the box content gets put. Normally
 this is defined in the theme, but if for some reason someone blanked
 the template out this will fill in.
 
-The default template is 'base_box::main_box_shell', which as the name
-would indicate is installed with this package. (OpenInteract will
-probably standardize to a 'package::template' naming convention in the
-relatively near future.)
+The default template is C<base_box::main_box_shell>, which as the name
+would indicate is installed with this package. 
+
+=item *
+
+B<system_box_handler> ($) (optional)
+
+Defines what we should run on every request to display system
+boxes. See
+L<OpenInteract::Handler::SystemBoxes|OpenInteract::Handler::SystemBoxes>
+for what this includes.
+
+It is okay if you blank this out, you just will not get the 'login',
+'templates_used' and other boxes on every page.
+
+=item *
+
+B<system_box_method> ($) (optional)
+
+Method to call on the C<system_box_handler> defined above.
+
+=item *
+
+B<custom_box_handler> ($) (optional)
+
+If you want to call a custom handler to run every time B<in addition
+to> the system handler named above, list the class here.
+
+=item *
+
+B<custom_box_method> ($) (optional)
+
+Method to call on the C<custom_box_handler> named above.
 
 =back
 
@@ -438,7 +558,8 @@ need to allow each box to define its own wrapper.
 
 =head1 SEE ALSO
 
-L<OpenInteract::SiteTemplate>, L<OpenInteract::Theme>
+L<OpenInteract::SiteTemplate|OpenInteract::SiteTemplate>,
+L<OpenInteract::Theme|OpenInteract::Theme>
 
 =head1 COPYRIGHT
 
