@@ -1,15 +1,17 @@
 package OpenInteract::Handler::Page;
 
-# $Id: Page.pm,v 1.37 2002/02/15 22:03:59 lachoy Exp $
+# $Id: Page.pm,v 1.39 2002/12/14 03:34:22 lachoy Exp $
 
 use strict;
 use Class::Date ();
+use File::Basename;
+use File::Spec;
 use OpenInteract::CommonHandler qw( OK ERROR );
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::Page::ISA     = qw( OpenInteract::CommonHandler  SPOPS::Secure );
-$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.37 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.39 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::Page::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Page::default_method    = 'show';
 @OpenInteract::Handler::Page::forbidden_methods = ();
@@ -24,7 +26,7 @@ use constant DEFAULT_EXPIRE  => '365D';
 
 # Use this to check whether the file retrieved is displayable in the
 # browser and in the normal template setup; others (pdf, ps, mov,
-# etc.) get sent to the user directly 
+# etc.) get sent to the user directly
 
 my %DISPLAY_TYPES = map { $_ => 1 } ( 'text/html' );
 
@@ -69,7 +71,7 @@ sub MY_EDIT_FIELDS_DATE        { return qw( active_on expires_on ) }
 sub MY_ALLOW_EDIT              { return 1 }
 
 sub MY_REMOVE_FAIL_TASK        { return 'show' }
-sub MY_REMOVE_DISPLAY_TASK     { return 'search_form' }
+sub MY_REMOVE_DISPLAY_TASK     { return 'show_remove' }
 sub MY_ALLOW_REMOVE            { return 1 }
 
 sub MY_ALLOW_NOTIFY            { return 1 }
@@ -86,7 +88,9 @@ sub actions {
 }
 
 
-my %HELP_MAP = ( upload => 'page_upload_help' );
+my %HELP_MAP = ( upload => 'page_upload_help',
+                 rename => 'page_rename_help' );
+
 
 sub help {
     my ( $class, $p ) = @_;
@@ -169,6 +173,252 @@ sub directory_list {
                                   { name => 'base_page::page_directory_list' } );
 }
 
+########################################
+# REMOVE DISPLAY
+
+sub show_remove {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $location = $class->_read_field( $R->apache, 'location' );
+    unless ( $location ) {
+        return $class->search_form( $p );
+    }
+    my $dirname = File::Basename::dirname( $location );
+    $p->{location} = $dirname;
+    return $class->show( $p );
+}
+
+########################################
+# CREATE SUBDIR
+
+# Display form to add subdirectory to $parent_dir
+
+sub specify_subdirectory {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $parent_dir = $class->_read_field( $R->apache, 'parent_directory' );
+    unless ( $class->_check_location_writable( $parent_dir ) ) {
+        $R->scrib( 0, "Insufficient permissions to add subdirectory" );
+        my $error_msg = "Insufficient permissions to add subdirectory. No action taken.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::directory_edit_status' } );
+    }
+    return $R->template->handler( {}, { parent_directory => $parent_dir },
+                                  { name => 'base_page::directory_form_simple' } );
+}
+
+
+# Add subdirectory $cleaned_dir to $parent_dir
+
+sub add_subdirectory {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $parent_dir = $class->_read_field( $R->apache, 'parent_directory' );
+    unless ( $class->_check_location_writable( $parent_dir ) ) {
+        $R->scrib( 0, "Insufficient permissions to add subdirectory" );
+        my $error_msg = "Insufficient permissions to add subdirectory. No action taken.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::directory_edit_status' } );
+    }
+
+    my $cleaned_dir = $R->page->clean_filename(
+                              $class->_read_field( $R->apache, 'directory' ) );
+    my $page_dir = File::Spec->catdir( $parent_dir, $cleaned_dir );
+    my $display_path = join( '/', $parent_dir, $cleaned_dir );
+    $display_path =~ s|/+|/|g;
+    my $full_dir = File::Spec->catdir( $R->config->get_dir( 'html' ), $page_dir );
+    eval { File::Path::mkpath( $full_dir, undef, 0775 ) };
+
+    my %params = ( parent_directory  => $parent_dir,
+                   created_directory => $display_path,
+                   action            => 'add_subdirectory' );
+    if ( $@ ) {
+        $params{error_msg} = "Failed to create [$display_path]: $@";
+    }
+    else {
+        $params{status_msg} = "Directory [$display_path] created ok";
+    }
+    return $R->template->handler( {}, \%params,
+                                  { name => 'base_page::directory_edit_status' } );
+}
+
+
+# NOTE: This removes a directory and all files underneath. This can
+# obviously be very dangerous, so you should ensure the user doesn't
+# call this accidentally by setting the parameter
+# 'remove_directory_confirm' to 'yes'.
+
+sub remove_directory {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $confirm = lc $class->_read_field( $R->apache, 'remove_directory_confirm' );
+    my $directory = $R->page->clean_name(
+                              $class->_read_field( $R->apache, 'directory' ) );
+
+    # Get rid of the trailing separator so we can find the pages with
+    # this directory value in the database (they always have the
+    # trailing separator removed)
+
+    $directory =~ s|/$||;
+
+    if ( ! $directory or $directory eq '/' ) {
+        $R->scrib( 0, "Empty/root directory given [$directory]; no action taken" );
+        my $error_msg = 'Directory removal cancelled: must specify a non-root directory';
+        return $R->template->handler( {}, { error_msg => $error_msg,
+                                            action    => 'remove_directory' },
+                                      { name => 'base_page::directory_edit_status' } );
+    }
+
+    if ( $confirm eq 'no' ) {
+        $R->DEBUG && $R->scrib( 1, "Directory removal cancelled" );
+        return $class->show({ location   => $directory,
+                              status_msg => 'Directory removal cancelled' });
+    }
+
+    if ( $confirm ne 'yes' ) {
+        $R->DEBUG && $R->scrib( 1, "Need confirmation for directory removal" );
+        return $R->template->handler( {}, { directory => $directory },
+                                      { name => 'base_page::directory_remove_confirm' } );
+    }
+
+    unless ( $class->_check_location_writable( $directory ) ) {
+        $R->scrib( 0, "Insufficient permissions to remove directory" );
+        my $error_msg = "Insufficient permissions to remove directory. No action taken.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::directory_edit_status' } );
+    }
+
+    $R->DEBUG && $R->scrib( 1, "Removal of dir [$directory] confirmed by user" );
+    eval {
+        my $pages_in_dir = $R->page->fetch_group({ where => 'directory LIKE ?',
+                                                   value => [ "$directory%" ] });
+        foreach my $page ( @{ $pages_in_dir } ) {
+            $R->DEBUG && $R->scrib( 1, "Removing page [$page->{location}]" );
+            $page->remove;
+            $R->DEBUG && $R->scrib( 1, "Removed page [$page->{location}] ok" );
+        }
+        my $full_dir = File::Spec->catdir( $R->config->get_dir( 'html' ), $directory );
+        $R->DEBUG && $R->scrib( 1, "Removing directory [$full_dir] from filesystem" );
+        File::Path::rmtree( $full_dir );
+        $R->DEBUG && $R->scrib( 1, "Removed directory [$full_dir] ok" );
+    };
+    if ( $@ ) {
+        $R->scrib( 0, "Error in removal process: $@" );
+        my $error_msg = "Failed to remove directory tree. Files may be in " .
+                     "inconsistent state. (Error: $@)";
+        return $R->template->handler( {}, { error_msg => $error_msg,
+                                            action    => 'remove_directory' },
+                                      { name => 'base_page::directory_edit_status' } );
+    }
+    $R->DEBUG && $R->scrib( 1, "Removal of directory [$directory] ok" );
+    my @pieces = split( '/', $directory );
+    pop @pieces;
+    my $view_directory = join( '/', @pieces );
+    $R->DEBUG && $R->scrib( 1, "Trying to view directory [$view_directory]" );
+    return $R->template->handler( {}, { status_msg       => "Removed directory [$directory] ok",
+                                        directory        => $directory,
+                                        parent_directory => $view_directory,
+                                        action           => 'remove_directory' },
+                                  { name => 'base_page::directory_edit_status' } );
+}
+
+
+########################################
+# RENAME FILE/PAGE
+
+sub specify_rename {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $location = $class->_read_field( $R->apache, 'location' );
+    unless ( $class->_check_location_writable( $location ) ) {
+        $R->scrib( 0, "Insufficient permissions to rename file" );
+        my $error_msg = "Insufficient permissions to rename file. No action taken.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+    my ( $error_msg );
+    my $page = eval { $R->page->fetch( $location ) };
+    if ( $@ ) {
+        $error_msg = "Failed to retrieve page for specified location [$location]";
+    }
+    return $R->template->handler( {}, { page      => $page,
+                                        error_msg => $error_msg },
+                                  { name => 'base_page::page_form_rename' } );
+}
+
+sub rename_file {
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $old_location = $class->_read_field( $R->apache, 'old_location' );
+    my $new_location = $R->page->clean_name(
+                              $class->_read_field( $R->apache, 'new_location' ) );
+    $R->DEBUG && $R->scrib( 1, "Trying to rename [$old_location] -> [$new_location]" );
+    unless ( $class->_check_location_writable( $old_location ) && 
+             $class->_check_location_writable( $new_location ) ) {
+        $R->scrib( 0, "Insufficient permissions to rename file" );
+        my $error_msg = "Insufficient permissions to rename file. No action taken.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+
+    my $old_page = $R->page->fetch( $old_location );
+    unless ( $old_page ) {
+        $R->scrib( 0, "Old location [$old_location] does not exist" );
+        my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
+                     "[$old_location] does not exist";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+    $R->DEBUG && $R->scrib( 1, "Old location fetched ok" );
+
+    my $new_page = $R->page->fetch( $new_location );
+    if ( $new_page ) {
+        $R->scrib( 0, "New location [$new_location] already exists" );
+        my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
+                     "[$new_location] already exists!";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+    $R->DEBUG && $R->scrib( 1, "New location does not exist (ok)" );
+
+    $old_page->{location} = $new_location;
+    eval { $old_page->rename_content( $old_location ) };
+    if ( $@ ) {
+        $R->scrib( 0, "Error renaming content: $@" );
+        my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
+                        "Failed to rename filesystem content to new location: $@.";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+    $R->DEBUG && $R->scrib( 1, "Page content renamed successfully" );
+
+    $R->DEBUG && $R->scrib( 1, "Saving page with new location [$old_page->{location}]" );
+    eval { $old_page->save({ use_id => $old_location }) };
+    if ( $@ ) {
+        $R->scrib( 0, "Error saving page object: $@" );
+        my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
+                        "Error saving page with new location: $@";
+        return $R->template->handler( {}, { error_msg => $error_msg },
+                                      { name => 'base_page::page_edit_status' } );
+    }
+    $R->DEBUG && $R->scrib( 1, "Page saved with new location ok" );
+
+    return $R->template->handler( {}, { status_msg => "File renamed ok",
+                                        directory  => $old_page->{directory},
+                                        location   => $old_page->{location} },
+                                  { name => 'base_page::page_edit_status' } );
+}
+
+sub _check_location_writable {
+    my ( $class, $location ) = @_;
+    my $R = OpenInteract::Request->instance;
+    my $level = $R->page->check_security({ object_id => $location,
+                                           user      => $R->{auth}{user},
+                                           group     => $R->{auth}{group} });
+    return ( $level >= SEC_LEVEL_WRITE );
+}
+
+########################################
 
 # Override to first check for 'old_location' and THEN the normal ID
 
