@@ -1,6 +1,6 @@
 package OpenInteract::Handler::SiteSearch;
 
-# $Id: SiteSearch.pm,v 1.13 2002/01/02 02:43:56 lachoy Exp $
+# $Id: SiteSearch.pm,v 1.14 2003/02/17 21:41:43 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
@@ -12,7 +12,7 @@ BEGIN {
     };
 }
 @OpenInteract::Handler::SiteSearch::ISA               = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SiteSearch::VERSION           = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::SiteSearch::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SiteSearch::default_method    = 'search';
 @OpenInteract::Handler::SiteSearch::forbidden_methods = ();
@@ -33,7 +33,7 @@ sub search {
     $params->{keywords}  = $apr->param( 'keywords' );
 
     unless ( $params->{keywords} or $params->{search_id} ) {
-        my %nk_params = ( title => 'No Keywords',
+        my %nk_params = ( title       => 'No Keywords',
                           description => 'You did not give me any keywords to search, ' .
                                          'so I did not run a search. Please try again.'  );
         return $R->template->handler( {}, \%nk_params,
@@ -86,8 +86,6 @@ sub search {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 OpenInteract::Handler::SiteSearch - Perform searches using the FullText module.
@@ -156,6 +154,6 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
 
 =cut
