@@ -1,11 +1,12 @@
 package OpenInteract::Page::File;
 
-# $Id: File.pm,v 1.6 2002/01/30 17:50:54 lachoy Exp $
+# $Id: File.pm,v 1.8 2002/12/13 21:41:14 lachoy Exp $
 
 use strict;
 use File::Basename qw();
 use File::Copy     qw( cp );
 use File::Path     qw();
+use File::Spec;
 
 # Use this to mark the beginning and end of the "good" content in a
 # page in the filesystem; this allows you to use an HTML editor to
@@ -111,7 +112,7 @@ sub save {
 }
 
 
-sub rename {
+sub rename_content {
     my ( $class, $page, $old_location ) = @_;
     my $R = OpenInteract::Request->instance;
 
@@ -131,7 +132,8 @@ sub rename {
                 || die "Cannot remove [$full_old_location]: $!";
     };
     die "Failed to rename file: $@" if ( $@ );
-    $R->DEBUG && $R->scrib( 1, "Renaming of file went ok. Now to check object" );
+    $R->DEBUG && $R->scrib( 1, "Renaming of file from [$full_old_location] to ",
+                               "[$full_new_location] ok. Now check object" );
 
     # Ensure the 'size' and 'mime_type' fields are set properly
 
@@ -180,10 +182,10 @@ sub _create_file_location {
     my ( $class, $item ) = @_;
     my $location = ( ref $item ) ? $item->{location} : $item;
     my $R = OpenInteract::Request->instance;
-    my $html_dir = $R->CONFIG->get_dir( 'html' );
-    $html_dir =~ s|/$||;
-    $R->DEBUG && $R->scrib( 1, "Trying to find filesystem location for [$html_dir] [$location]" );
-    return join( '', $html_dir, $location );
+    my $full_location = File::Spec->catfile( $R->CONFIG->get_dir( 'html' ),
+                                             $location );
+    $R->DEBUG && $R->scrib( 1, "Trying to find filesystem location for [$full_location]" );
+    return $full_location;
 }
 
 
@@ -194,13 +196,13 @@ sub _create_location_path {
 
     my $dirname = File::Basename::dirname( $location );
     if ( -d $dirname ) {
-        $R->DEBUG && $R->scrib( 1, "Path for [$location] already exists" );
+        $R->DEBUG && $R->scrib( 1, "Path [$dirname] [$location] already exists" );
         return 1;
     }
 
     eval { File::Path::mkpath( $dirname, undef, 0775 ) };
     unless ( $@ ) {
-        $R->DEBUG && $R->scrib( 1, "Path for [$location] created ok" );
+        $R->DEBUG && $R->scrib( 1, "Path [$dirname] for [$location] created ok" );
         return 1;
     }
     $R->scrib( 0, "Cannot create path [$dirname]: $@" );
