@@ -7,8 +7,8 @@ CREATE TABLE page (
  boxes            varchar(75),
  template_parse   char(3) default 'yes',
  main_template    varchar(40),
- active_on        datetime,
- expires_on       datetime,
+ active_on        timestamp,
+ expires_on       timestamp,
  is_active        char(3) default 'no',
  content_location varchar(150),
  storage          varchar(10) default 'database',
